@@ -1,6 +1,6 @@
 # ABSTRACT: Creates db_util command line for DB_File management
 package DB_File::Utils;
-$DB_File::Utils::VERSION = '0.003';
+$DB_File::Utils::VERSION = '0.004';
 use DB_File;
 use Fcntl;
 
@@ -11,19 +11,30 @@ sub global_opt_spec {
      ['u|utf8' => "Force UTF8 encoding/decoding on values."],
      ['btree' => "Use BTree indexing method (default)"],
      ['hash'  => "Use Hash indexing method"],
-  #   ['recno' => "Use RecNo indexing method"],
+     ['recno' => "Use RecNo indexing method"],
   );
 }
 
 sub do_tie {
 	my ($self, $file, $ops) = @_;
 
-	my %hash;
-	my $method = $ops->{recno} ? $DB_RECNO : ($ops->{hash} ? $DB_HASH : $DB_BTREE);
-  my $mode   = $ops->{_create_} ? (O_CREAT | O_RDWR) : O_RDWR;
-	tie %hash, 'DB_File', $file, $mode, '0666', $method;
+    my $mode   = $ops->{_create_} ? (O_CREAT | O_RDWR) : O_RDWR;
+	if ($ops->{recno}) {
+		my @array;
+		my $method = $DB_RECNO;
 
-	return \%hash;
+		tie @array, 'DB_File', $file, $mode, '0666', $method;
+
+		return \@array;
+	}
+	else {
+		my %hash;
+		my $method = $ops->{hash} ? $DB_HASH : $DB_BTREE;
+
+		tie %hash, 'DB_File', $file, $mode, '0666', $method;
+
+		return \%hash;
+	}
 }
 
 
