@@ -1,5 +1,5 @@
 package DB_File::Utils::Command::put;
-$DB_File::Utils::Command::put::VERSION = '0.003';
+$DB_File::Utils::Command::put::VERSION = '0.004';
 use v5.20;
 use DB_File::Utils -command;
 use strict;
@@ -7,6 +7,7 @@ use warnings;
 
 use DB_File;
 use Fcntl;
+use File::Slurp;
 
 sub abstract { "Sets the value for a specific key" }
 
@@ -15,7 +16,9 @@ sub description { "Given a DB_File with strings as keys, sets or ressets the val
 sub usage_desc { $_[0]->SUPER::usage_desc . ' <dbfile> <key>' }
 
 sub opt_spec {
-	return ();
+	return (
+       ['input|i=s' => "Read value from filename, instead of stdin."],
+	);
 }
 
 sub validate_args {
@@ -25,6 +28,14 @@ sub validate_args {
 
 	$self->usage_error("$args->[0] not found") unless -f $args->[0];
 
+	if (exists($opt->{input})) {
+		$self->usage_error("$opt->{input} not found") unless -f $opt->{input};		
+	}
+
+	if ($self->app->global_options->{recno} && $args->[1] !~ /^\d+$/) {
+		$self->usage_error("RecNo indexing scheme only support integer keys");
+	}
+
 }
 
 sub execute {
@@ -36,7 +47,11 @@ sub execute {
 	my $key  = $args->[1];
 
 	my $contents;
-	{
+	if ($opt->{input}) {
+		$contents = read_file($opt->{input},
+							  $opt->{utf8} ? { binmode => ':utf8'} : ());
+	}
+	else {
 		local $/ = undef;
 		binmode STDIN, ':utf8' if $opt->{utf8};
 		$contents = <STDIN>;
@@ -47,10 +62,13 @@ sub execute {
 
 sub _store {
 	my ($self, $filename, $key, $value, $opt) = @_;
-	my $hash = $self->app->do_tie( $filename, $opt);
-
-	$hash->{$key} = $opt->{utf8} ? encode('utf-8', $value) : $value;
-	untie $hash;
+	my $collection = $self->app->do_tie( $filename, $opt);
+	if (ref($collection) eq "HASH") {
+		$collection->{$key} = $opt->{utf8} ? encode('utf-8', $value) : $value;
+	} else {
+		$collection->[$key] = $opt->{utf8} ? encode('utf-8', $value) : $value;
+	}
+	untie $collection;
 }
 
 1;
\ No newline at end of file
